@@ -1,5 +1,5 @@
 
-# Copyright (C) 2012 - 2020  JJ Allaire, Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2012 - 2021  JJ Allaire, Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -28,7 +28,8 @@ sourceCpp <- function(file = "",
                       showOutput = verbose,
                       verbose = getOption("verbose"),
                       dryRun = FALSE,
-                      windowsDebugDLL = FALSE) {
+                      windowsDebugDLL = FALSE,
+                      echo = TRUE) {
 
     # use an architecture/version specific subdirectory of the cacheDir
     # (since cached dynlibs can now perist across sessions we need to be
@@ -127,17 +128,25 @@ sourceCpp <- function(file = "",
             file.remove(context$previousDynlibPath)
         }                                                       # #nocov end
 
+        # grab components we need to build command
+        r <- paste(R.home("bin"), "R", sep = .Platform$file.sep)
+        lib  <- context$dynlibFilename
+        deps <- context$cppDependencySourcePaths
+        src  <- context$cppSourceFilename
+
         # prepare the command (output if we are in showOutput mode)
-        cmd <- paste(R.home(component="bin"), .Platform$file.sep, "R ",
-                     "CMD SHLIB ",
-                     ifelse(windowsDebugDLL, "-d ", ""),
-                     "-o ", shQuote(context$dynlibFilename), " ",
-                     ifelse(rebuild, "--preclean ", ""),
-                     ifelse(dryRun, "--dry-run ", ""),
-                     paste(shQuote(context$cppDependencySourcePaths),
-                           collapse = " "), " ",
-                     shQuote(context$cppSourceFilename), " ",
-                     sep="")
+        args <- c(
+            r, "CMD", "SHLIB",
+            if (windowsDebugDLL) "-d",
+            if (rebuild) "--preclean",
+            if (dryRun) "--dry-run",
+            "-o", shQuote(lib),
+            if (length(deps))
+                paste(shQuote(deps), collapse = " "),
+            shQuote(src)
+        )
+
+        cmd <- paste(args, collapse = " ")
         if (showOutput)
             cat(cmd, "\n")										# #nocov
 
@@ -206,7 +215,7 @@ sourceCpp <- function(file = "",
     if (embeddedR && (length(context$embeddedR) > 0)) {
         srcConn <- textConnection(context$embeddedR)
         setwd(rWorkingDir) # will be reset by previous on.exit handler
-        source(file = srcConn, local = env, echo = TRUE)
+        source(file = srcConn, local = env, echo = echo)
     }
 
     # cleanup the cache dir if requested
@@ -250,7 +259,8 @@ cppFunction <- function(code,
                         rebuild = FALSE,
                         cacheDir = getOption("rcpp.cache.dir", tempdir()),
                         showOutput = verbose,
-                        verbose = getOption("verbose")) {
+                        verbose = getOption("verbose"),
+                        echo = TRUE) {
 
     # process depends
     if (!is.null(depends) && length(depends) > 0) {             # #nocov start
@@ -307,7 +317,8 @@ cppFunction <- function(code,
                           rebuild = rebuild,
                           cacheDir = cacheDir,
                           showOutput = showOutput,
-                          verbose = verbose)
+                          verbose = verbose,
+                          echo = echo)
 
     # verify that a single function was exported and return it
     if (length(exported$functions) == 0)
@@ -429,7 +440,7 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
     # create R directory if it doesn't already exist
     rDir <- file.path(pkgdir, "R")
     if (!file.exists(rDir))
-        dir.create(rDir)
+        dir.create(rDir)														# #nocov
 
     # remove the old RcppExports.R file
     unlink(file.path(rDir, "RcppExports.R"))
